@@ -10,9 +10,15 @@
 #'  - A call to the function with `.` as a dummy argument,
 #'    `mean(., na.rm = TRUE)`
 #'
-#'   These arguments are automatically [quoted][rlang::quo]. They
-#'   support [unquoting][rlang::quasiquotation] and splicing. See
-#'   `vignette("programming")` for an introduction to these concepts.
+#'  These arguments are automatically [quoted][rlang::quo]. They
+#'  support [unquoting][rlang::quasiquotation] and splicing. See
+#'  `vignette("programming")` for an introduction to these concepts.
+#'
+#'  The following notations are **not** supported, see examples:
+#'
+#'  - An anonymous function, `function(x) mean(x, na.rm = TRUE)`
+#'  - An anonymous function in \pkg{purrr} notation, `~mean(., na.rm = TRUE)`
+#'
 #' @param .args,args A named list of additional arguments to be added
 #'   to all function calls.
 #' @export
@@ -25,6 +31,11 @@
 #' # If you have function names in a vector, use funs_
 #' fs <- c("min", "max")
 #' funs_(fs)
+#'
+#' # Not supported
+#' \dontrun{
+#' funs(function(x) mean(x, na.rm = TRUE))
+#' funs(~mean(x, na.rm = TRUE))}
 funs <- function(..., .args = list()) {
   dots <- quos(...)
   default_env <- caller_env()
@@ -37,7 +48,7 @@ new_funs <- function(funs) {
 
   missing_names <- names(funs) == ""
   default_names <- map_chr(funs[missing_names], function(dot) {
-    quo_name(node_car(f_rhs(dot)))
+    quo_name(node_car(quo_get_expr(dot)))
   })
   names(funs)[missing_names] <- default_names
 
@@ -51,10 +62,10 @@ as_fun_list <- function(.x, .quo, .env, ...) {
   force(.quo)
 
   # If a fun_list, update args
-  args <- dots_list(...)
+  args <- list2(...)
   if (is_fun_list(.x)) {
     if (!is_empty(args)) {
-      .x[] <- map(.x, lang_modify, !!! args)
+      .x[] <- map(.x, lang_modify, !!!args)
     }
     return(.x)
   }
@@ -80,20 +91,30 @@ as_fun <- function(.x, .env, .args) {
 
   # For legacy reasons, we support strings. Those are enclosed in the
   # empty environment and need to be switched to the caller environment.
-  f_env(quo) <- fun_env(quo, .env)
+  quo <- quo_set_env(quo, fun_env(quo, .env))
+
+  expr <- quo_get_expr(quo)
+
+  if (is_lang(expr, c("function", "~"))) {
+    top_level <- fmt_calls(expr[[1]])
+    bad_args(quo_text(expr), "must be a function name (quoted or unquoted) or an unquoted call, not {top_level}")
+  }
 
-  expr <- get_expr(.x)
   if (is_lang(expr) && !is_lang(expr, c("::", ":::"))) {
-    expr <- lang_modify(expr, !!! .args)
+    expr <- lang_modify(expr, !!!.args)
   } else {
-    expr <- lang(expr, quote(.), !!! .args)
+    expr <- lang(expr, quote(.), !!!.args)
   }
 
   set_expr(quo, expr)
 }
 
+quo_as_function <- function(quo) {
+  new_function(exprs(. = ), quo_get_expr(quo), quo_get_env(quo))
+}
+
 fun_env <- function(quo, default_env) {
-  env <- f_env(quo)
+  env <- quo_get_env(quo)
   if (is_null(env) || identical(env, empty_env())) {
     default_env
   } else {
@@ -101,7 +122,7 @@ fun_env <- function(quo, default_env) {
   }
 }
 
-is_fun_list <- function(x, env) {
+is_fun_list <- function(x) {
   inherits(x, "fun_list")
 }
 #' @export
@@ -116,7 +137,7 @@ print.fun_list <- function(x, ..., width = getOption("width")) {
   cat("<fun_calls>\n")
   names <- format(names(x))
 
-  code <- map_chr(x, function(x) deparse_trunc(f_rhs(x), width - 2 - nchar(names[1])))
+  code <- map_chr(x, function(x) deparse_trunc(quo_get_expr(x), width - 2 - nchar(names[1])))
 
   cat(paste0("$ ", names, ": ", code, collapse = "\n"))
   cat("\n")
@@ -129,5 +150,5 @@ print.fun_list <- function(x, ..., width = getOption("width")) {
 #' @param env The environment in which functions should be evaluated.
 funs_ <- function(dots, args = list(), env = base_env()) {
   dots <- compat_lazy_dots(dots, caller_env())
-  funs(!!! dots, .args = args)
+  funs(!!!dots, .args = args)
 }
