@@ -12,13 +12,19 @@
 .onAttach <- function(libname, pkgname) {
   setHook(packageEvent("plyr", "attach"), function(...) {
     packageStartupMessage(rule())
-    packageStartupMessage("You have loaded plyr after dplyr - this is likely ",
+    packageStartupMessage(
+      "You have loaded plyr after dplyr - this is likely ",
       "to cause problems.\nIf you need functions from both plyr and dplyr, ",
-      "please load plyr first, then dplyr:\nlibrary(plyr); library(dplyr)")
+      "please load plyr first, then dplyr:\nlibrary(plyr); library(dplyr)"
+    )
     packageStartupMessage(rule())
   })
 }
 
+.onDetach <- function(libpath) {
+  setHook(packageEvent("plyr", "attach"), NULL, "replace")
+}
+
 when_attached <- function(pkg, action) {
   if (is_attached(pkg)) {
     action
