@@ -67,7 +67,7 @@ mutate_y(df1)
 df <- tibble(
   g1 = c(1, 1, 2, 2, 2),
   g2 = c(1, 2, 1, 2, 1),
-  a = sample(5), 
+  a = sample(5),
   b = sample(5)
 )
 
@@ -102,7 +102,7 @@ my_summarise(df, quo(g1))
 ## ------------------------------------------------------------------------
 my_summarise <- function(df, group_var) {
   df %>%
-    group_by(!!group_var) %>%
+    group_by(!! group_var) %>%
     summarise(a = mean(a))
 }
 
@@ -112,24 +112,24 @@ my_summarise(df, quo(g1))
 #  my_summarise(df, g1)
 
 ## ---- error = TRUE-------------------------------------------------------
-my_summarise <- function(df, group_by) {
-  quo_group_by <- quo(group_by)
-  print(quo_group_by)
+my_summarise <- function(df, group_var) {
+  quo_group_var <- quo(group_var)
+  print(quo_group_var)
 
   df %>%
-    group_by(!!quo_group_by) %>%
+    group_by(!! quo_group_var) %>%
     summarise(a = mean(a))
 }
 
 my_summarise(df, g1)
 
 ## ------------------------------------------------------------------------
-my_summarise <- function(df, group_by) {
-  group_by <- enquo(group_by)
-  print(group_by)
+my_summarise <- function(df, group_var) {
+  group_var <- enquo(group_var)
+  print(group_var)
 
   df %>%
-    group_by(!!group_by) %>%
+    group_by(!! group_var) %>%
     summarise(a = mean(a))
 }
 
@@ -141,22 +141,22 @@ summarise(df, mean = mean(a * b), sum = sum(a * b), n = n())
 
 ## ------------------------------------------------------------------------
 my_var <- quo(a)
-summarise(df, mean = mean(!!my_var), sum = sum(!!my_var), n = n())
+summarise(df, mean = mean(!! my_var), sum = sum(!! my_var), n = n())
 
 ## ------------------------------------------------------------------------
-quo(summarise(df, 
-  mean = mean(!!my_var),
-  sum = sum(!!my_var),
+quo(summarise(df,
+  mean = mean(!! my_var),
+  sum = sum(!! my_var),
   n = n()
 ))
 
 ## ------------------------------------------------------------------------
 my_summarise2 <- function(df, expr) {
   expr <- enquo(expr)
-  
-  summarise(df, 
-    mean = mean(!!expr),
-    sum = sum(!!expr),
+
+  summarise(df,
+    mean = mean(!! expr),
+    sum = sum(!! expr),
     n = n()
   )
 }
@@ -172,10 +172,10 @@ my_mutate <- function(df, expr) {
   expr <- enquo(expr)
   mean_name <- paste0("mean_", quo_name(expr))
   sum_name <- paste0("sum_", quo_name(expr))
-  
-  mutate(df, 
-    !!mean_name := mean(!!expr), 
-    !!sum_name := sum(!!expr)
+
+  mutate(df,
+    !! mean_name := mean(!! expr),
+    !! sum_name := sum(!! expr)
   )
 }
 
@@ -183,10 +183,10 @@ my_mutate(df, a)
 
 ## ------------------------------------------------------------------------
 my_summarise <- function(df, ...) {
-  group_by <- quos(...)
+  group_var <- quos(...)
 
   df %>%
-    group_by(!!!group_by) %>%
+    group_by(!!! group_var) %>%
     summarise(a = mean(a))
 }
 
@@ -253,12 +253,12 @@ get_env(var)
 quo(toupper(letters[1:5]))
 
 # Here we capture the value of `letters[1:5]`
-quo(toupper(!!letters[1:5]))
+quo(toupper(!! letters[1:5]))
 quo(toupper(UQ(letters[1:5])))
 
 ## ------------------------------------------------------------------------
 var1 <- quo(letters[1:5])
-quo(toupper(!!var1))
+quo(toupper(!! var1))
 
 ## ------------------------------------------------------------------------
 my_mutate <- function(x) {
@@ -277,11 +277,11 @@ my_mutate(expr2)
 
 ## ---- error = TRUE-------------------------------------------------------
 my_fun <- quo(fun)
-quo(!!my_fun(x, y, z))
+quo(!! my_fun(x, y, z))
 quo(UQ(my_fun)(x, y, z))
 
 my_var <- quo(x)
-quo(filter(df, !!my_var == 1))
+quo(filter(df, !! my_var == 1))
 quo(filter(df, UQ(my_var) == 1))
 
 ## ------------------------------------------------------------------------
@@ -296,7 +296,7 @@ x <- list(foo = 1L, bar = quo(baz))
 quo(list(!!! x))
 
 ## ------------------------------------------------------------------------
-args <- list(mean = quo(mean(cyl)), count = quo(n())) 
+args <- list(mean = quo(mean(cyl)), count = quo(n()))
 mtcars %>%
   group_by(am) %>%
   summarise(!!! args)
@@ -308,7 +308,7 @@ count_nm <- "count"
 mtcars %>%
   group_by(am) %>%
   summarise(
-    !!mean_nm := mean(cyl),
-    !!count_nm := n()
+    !! mean_nm := mean(cyl),
+    !! count_nm := n()
   )
 
