@@ -13,6 +13,7 @@
 #include <dplyr/Result/CallProxy.h>
 
 #include <dplyr/bad.h>
+#include <dplyr/tbl_cpp.h>
 
 using namespace Rcpp;
 using namespace dplyr;
@@ -68,7 +69,7 @@ DataFrame filter_grouped(const SlicedTibble& gdf, const NamedQuosure& quo) {
   }
 
   // Subset the grouped data frame
-  DataFrame res = subset(data, test, data.names(), classes_grouped<SlicedTibble>());
+  DataFrame res = subset(data, test, classes_grouped<SlicedTibble>());
   copy_vars(res, data);
   strip_index(res);
   return SlicedTibble(res).data();
