@@ -21,7 +21,7 @@ using namespace dplyr;
 // [[Rcpp::export]]
 IntegerVector grouped_indices_grouped_df_impl(GroupedDataFrame gdf) {
   int n = gdf.nrows();
-  IntegerVector res = no_init(n);
+  IntegerVector res(no_init(n));
   int ngroups = gdf.ngroups();
   GroupedDataFrameIndexIterator it = gdf.group_begin();
   for (int i = 0; i < ngroups; i++, ++it) {
@@ -74,7 +74,7 @@ void build_index_cpp(DataFrame& data) {
   labels = DataFrameSubsetVisitors(labels).subset(labels_order, "data.frame");
 
   List indices(ngroups);
-  IntegerVector group_sizes = no_init(ngroups);
+  IntegerVector group_sizes(no_init(ngroups));
   int biggest_group = 0;
 
   ChunkIndexMap::const_iterator it = map.begin();
